aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--controlloop/common/simulators/src/main/java/org/onap/policy/simulators/SdncSimulatorJaxRs.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/controlloop/common/simulators/src/main/java/org/onap/policy/simulators/SdncSimulatorJaxRs.java b/controlloop/common/simulators/src/main/java/org/onap/policy/simulators/SdncSimulatorJaxRs.java
index 4b22fa3ff..bf1ec0b1a 100644
--- a/controlloop/common/simulators/src/main/java/org/onap/policy/simulators/SdncSimulatorJaxRs.java
+++ b/controlloop/common/simulators/src/main/java/org/onap/policy/simulators/SdncSimulatorJaxRs.java
@@ -57,12 +57,12 @@ public class SdncSimulatorJaxRs {
}
/**
* SDNC vnf topology operation.
*
* @return the response
*/
@POST
- @Path("/GENERIC-RESOURCE-API:vnf-topology-operation")
+ @Path("/GENERIC-RESOURCE-API:vf-module-topology-operation")
@Consumes(MediaType.APPLICATION_JSON)
@Produces("application/json")
public String sdncVnfTopologyOperation() {
@@ -57,12 +57,12 @@ public class SdncSimulatorJaxRs {
}
/**
- * SDNC vnf topology operation.
+ * SDNC vf module topology operation.
*
* @return the response